#!/bin/sh
# shellcheck disable=SC2015
set -e

read_conf() # $1=local_context, $2=var, $3=default
{
	printf %s "$1" | tr '\r' '\n' | grep "^$2=" | cut -d= -f2- | grep . || printf %s "$3"
}
read_multiline_conf() # $1=local_context, $2=var, $3=default
{
	printf %s "$1" | grep "^$2=" | cut -d= -f2- | tr '\r' '\n' | grep . || printf %s "$3"
}

global_context()
{
	raw_context | while read -r line
	do
		if [ "$line" = \' ]
		then
			printf '\n'
			continue
		fi

		if printf %s "$line" | grep -Eq "='.*'\$"
		then
			printf '%s\n' "$line" | sed "s/='\(.*\)'\$/=\1/"
		else
			printf '%s\r' "$line" | sed "s/='\(.*\)\$/=\1/"
		fi
	done
}

raw_context()
{
	if [ -n "$CONTEXT" ]
	then
		printf '%s\n' "$CONTEXT"
		return
	fi
	[ -n "$LABEL" ] || LABEL=CONTEXT

	device="$(glabel status | grep -F "$LABEL" | awk '{print $3}')"

	# Test if the device is of the type we expect to be able to read naively and quickly
	if [ "$(file -s "/dev/$device")" = "/dev/cd0: ISO 9660 CD-ROM filesystem data '$LABEL'" ]
	then
		# Test if the device is small enough to read without mounting
		if glabel list "$device" | grep -F Mediasize: | cut -d: -f2 | grep -Fq K
		then
			# Extremely naive way to read the file directly from the ISO, but it works!
			grep -Fao -A99999 '# Context variables generated by OpenNebula' "/dev/$device" \
				| tr \\0 \\n \
				| sed -e '/^$/q' \
				| grep . \
					&& return || true
		fi

		# CD has the correct filesystem and name, but it's too big for us to try (over 1MB),
		# rather just mount it;
	fi

	dir="$(mktemp -d "/tmp/mount.XXXXXX" 2>/dev/null)"

	cleanup()
	{
		umount "$dir" 2>/dev/null
		rmdir "$dir" 2>/dev/null
	}
	trap cleanup EXIT

	mount_msdosfs "/dev/$device" "$dir" 2>/dev/null || mount_cd9660 "/dev/$device" "$dir" 2>/dev/null
	if ! test -f "$dir/context.sh"
	then
		echo '%s: Cannot find context.sh on cloud-init filesystem' "$0" >&2
	fi

	cat "$dir/context.sh"
}

interfaces()
{
	get_var() # $1=var, $2=default
	{
		printf %s "$CONTEXT" | grep "^$1=" | cut -d= -f2- | grep . || printf %s "$2"
	}
	CONTEXT="$(global_context)"

	if [ "$(get_var NETWORK)" != YES ]
	then
		printf '%s: Network is disabled in context.sh\n' "$0" >&2
		exit 2
	fi

	ETH=0
	success=0
	while printf %s "$CONTEXT" | grep -q "^ETH${ETH}_MAC="
	do
		mac="$(get_var "ETH${ETH}_MAC")"
		iface="$(ifconfig | grep -F "$mac" -B2 | head -n1 | cut -d: -f1)"

		if [ -n "$iface" ]
		then
			printf '%s\t%s\t%s\t%s\n' "$ETH" "$mac" "$iface" "$(printf %s "$CONTEXT" | grep "^ETH${ETH}_" | cut -d_ -f2- | tr \\n \\r)"
			success=1
		else
			printf '%s: Cannot find interface with MAC %s\n' "$0" "$mac" >&2
		fi

		ETH="$(("$ETH" + 1))"
	done

	[ "$success" = 1 ]
}