#!/bin/sh
# shellcheck disable=SC2015
set -e

SCRIPT_PATH="${SCRIPT_PATH:-$(dirname "$0")}"
. "${SCRIPT_PATH}/functions.sh"

# shellcheck disable=SC3003
IFS=$'\n' interfaces | while read -r _ mac iface context
do
	method6="$(read_conf "$context" IP6_METHOD static)"
	method4="$(read_conf "$context" METHOD static)"
	ip6="$(read_conf "$context" IP6)"
	ip6_ula="$(read_conf "$context" IP6_ULA)"
	ip4="$(read_conf "$context" IP)"
	prefix6="$(read_conf "$context" IP6_PREFIX_LENGTH 64)"
	mask4="$(read_conf "$context" MASK 255.255.255.0)"
	mtu="$(read_conf "$context" MTU)"
	alias=0

	# TODO: "external" (?)
	# TODO: metric (probably not supported?)
	# TODO: VLAN

	mtu_ifconfig=''
	[ -n "$mtu" ] && mtu_ifconfig="mtu $mtu"

	case "$method6" in
		static)
			ip6alias=0
			for ip in $ip6 $ip6_ula
			do
				if [ "$ip6alias" -eq 0 ]
				then
					printf 'ifconfig_%s_ipv6="inet6 %s prefixlen %s %s -accept_rtadv"\n' "$iface" "$ip" "$prefix6" "$mtu_ifconfig"
					ip6alias=1
				else
					printf 'ifconfig_%s_alias%s="inet6 %s prefixlen %s"\n' "$iface" "$alias" "$ip" "$prefix6"
					alias="$(("$alias" + 1))"
				fi
			done
			;;
		auto)
			printf 'ifconfig_%s_ipv6="inet6 accept_rtadv -no_radr"\n' "$iface"
			;;
		dhcp)
			printf 'Unsupported IP6_METHOD: %s\n' "$method6" >&2
			;;
		disable)
			printf 'ifconfig_%s_ipv6="inet6 -accept_rtadv"\n' "$iface"
			;;
		skip)
			;;
		*)
			printf 'Unknown IP6_METHOD: %s\n' "$method6" >&2
			;;
	esac

	case "$method4" in
		static)
			ip4alias=0
			for ip in $ip4
			do
				if [ "$ip4alias" -eq 0 ]
				then
					printf 'ifconfig_%s="inet %s netmask %s %s"\n' "$iface" "$ip" "$mask4" "$mtu_ifconfig"
					ip4alias=1
				else
					printf 'ifconfig_%s_alias%s="inet %s netmask %s"\n' "$iface" "$alias" "$ip" "$mask4"
					alias="$(("$alias" + 1))"
				fi
			done
			;;
		dhcp)
			printf 'ifconfig_%s="DHCP"\n' "$iface"
			;;
		skip)
			;;
		*)
			printf 'Unknown METHOD: %s\n' "$method4" >&2
			;;
	esac
done
