#!/bin/sh
# shellcheck disable=SC2015
set -e

SCRIPT_PATH="${SCRIPT_PATH:-$(dirname "$0")}"
. "${SCRIPT_PATH}/functions.sh"

# DNS configuration is *supposed* to be global, but some formats set DNS settings per interface.
# Try first to get a global DNS configuration and if that fails, do per interface.
context="$(global_context)"
dns="$(read_conf "$context" DNS)"
if [ -n "$dns" ]
then
	for nameserver in $dns
	do
		printf 'nameserver %s\n' "$nameserver"
	done
else
	# For interfaces, we will ignore nameservers that have an IP family that is not supported by the interface;
	# aka for an interface with only IPv6 addresses, we will ignore IPv4 nameserver.
	# shellcheck disable=SC3003
	IFS=$'\n' interfaces | while read -r _ mac iface context
	do
		ip6="$(read_conf "$context" IP6)"
		ip4="$(read_conf "$context" IP)"
		dns="$(read_conf "$context" DNS)"

		# TODO: search domain

	for nameserver in $dns
	do
		# Print IPv6 addresses only if we have an IPv6 address for this interface
		[ -n "$ip6" ] && printf 'nameserver %s\n' "$nameserver" | grep -F : && continue ||:
		# Print IPv4 addresses only if we have an IPv4 address for this interface
		[ -n "$ip4" ] && printf 'nameserver %s\n' "$nameserver" | grep -F . && continue ||:
	done
done
fi
